## 港股通十大成交股

接口：ggt_top10

描述：获取港股通每日成交数据，其中包括沪市、深市详细数据，每天18~20点之间完成当日更新

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码（二选一） |
| trade_date | str | N | 交易日期（二选一） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| market_type | str | N | 市场类型 2：港股通（沪） 4：港股通（深） |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| trade_date | str | 交易日期 |
| ts_code | str | 股票代码 |
| name | str | 股票名称 |
| close | float | 收盘价 |
| p_change | float | 涨跌幅 |
| rank | str | 资金排名 |
| market_type | str | 市场类型 2：港股通（沪） 4：港股通（深） |
| amount | float | 累计成交金额（元） |
| net_amount | float | 净买入金额（元） |
| sh_amount | float | 沪市成交金额（元） |
| sh_net_amount | float | 沪市净买入金额（元） |
| sh_buy | float | 沪市买入金额（元） |
| sh_sell | float | 沪市卖出金额 |
| sz_amount | float | 深市成交金额（元） |
| sz_net_amount | float | 深市净买入金额（元） |
| sz_buy | float | 深市买入金额（元） |
| sz_sell | float | 深市卖出金额（元） |

接口用法

```python
pro = ts.pro_api()

pro.ggt_top10(trade_date='20180727')
```

或者

```python
pro.query('ggt_top10', ts_code='00700', start_date='20180701', end_date='20180727')
```

数据样例

```python
trade_date ts_code       name   close   p_change  rank   market_type  \
0    20180727   00175    吉利汽车   18.42   -3.2563   4.0            2   
```